@@ -889,18 +889,16 @@ PluginConfig = Dict[str, Any]
 JSONValue = Union[str, int, float, bool, Dict[str, Any], List[Any]]
 
 
+class ToastMessage(TypedDict, total=False):
+    toast: str
+
+
 class BasePlugin(ABC):
     @abstractmethod
     def __init__(self, logger: PluginLogger, api_instance: PluginAPI) -> None: ...
 
     @abstractmethod
-    def on_form_submit(
-        self, action_id: str, payload: Any
-    ) -> Optional[Dict[Any, Any]] | Coroutine[Any, Any, Optional[Dict[Any, Any]]]:
-        pass
+    def on_form_submit(self, action_id: str, payload: Any) -> ToastMessage: ...
 
     @abstractmethod
-    def configure_cameras(
-        self, cameras: List[CameraDevice]
-    ) -> None | Coroutine[Any, Any, None]:
-        pass
+    def configure_cameras(self, cameras: List[CameraDevice]) -> None: ...
